@@ -1,21 +1,19 @@
 from types import MethodWrapperType
 from sqlalchemy.pool import NullPool
 from fastapi_helpers.db import DbConfig
-from fastapi_helpers.logging import DefaultLogger
+from logging import getLogger
 from typing import Any
 
 class Worker:
 
     db_config: DbConfig
-    logger: DefaultLogger
 
     def __init__(
         self,
         db_config: DbConfig,
-        logger: DefaultLogger
     ) -> None:
         self.db_config = db_config
-        self.logger = logger
+        self.logger = getLogger("fastapi")
 
     def use_db_connection(self, func) -> MethodWrapperType:
         '''Decorator that connects to the db.'''
